#!/bin/sh
# \
exec wishx "$0" "$@"

#								 ***********
#								** Summary **
#								 ***********

#					  Copyright 2002, Nagual Enterprises
#				Please see COPYING for the complete GNU license

#	(1)	Title:
#				Daggerfall CIF Collection Viewer

#	(2)	Purpose:
#			To browse collections of Daggerfall CIF-style image
#			collections.

#	(3)	Platform dependencies:
#			***  None  ***

#	(4)	Change history:
#			Please see the RCS logs for change history.

#	(5)	Definitions:

#			Namespaces:
#				***  None  ***

#			Exports:
#				***  None  ***

#			Assertions about definitions:
#				***  None  ***

#	(6)	References:

#			Library files:
#				Tcl					--	Base Tcl support
#				Tk					--	Base widget support

#			Imports:
#				Arena2Config		--	Arena2 configuration
#				imgtocif.tcl		--	CIF collection accessor

#			Assertions about the references:
#				***  None  ***

#								 ********
#								** Text **
#								 ********

#							 *****************
#							** Configuration **
#							 *****************

source cifimg.tcl
	namespace import -force Arena2Cif::imageAt
	namespace import -force Arena2Cif::shortAt
	namespace import -force Arena2Cif::buildTables
	namespace import -force Arena2Cif::description
	namespace import -force Arena2Cif::cifFaces

source cifanime.tcl
if {[llength [namespace children :: ::Arena2Texture]] == 0} then {
	source texture.tcl
}

set font {Helvetica 14}
global faces
global needFaces
set faces ""
set needFaces 1
global dirName
set dirName "/dos/g/game/dag/arena2"

global faceTables

#							 *****************
#							** Class methods **
#							 *****************

proc fanimators {} {
	set reply {}
	if {[llength [namespace which -variable portraita]]} then {
		lappend reply $::portraita
	}
	return "$reply"
}

proc fpositionWindow w {
#		Position a new window on the screen.
	wm geometry $w +300+300
}

proc floadDir {w} {
#		Load a directory listbox with file names.

	global dirName
	$w.f.list delete 0 end
	foreach i [lsort [glob [file join $dirName *.cif] [file join $dirName *.cfa]]] {
		$w.f.list insert end [file tail $i]
	}
}

proc floadImageDir {w resNo} {
#		Load a listbox with texture image names.

	variable Arena2Cif::tableHeaders
	variable Arena2Cif::tableCount
	variable Arena2Cif::width
	variable Arena2Cif::height
	variable Arena2Cif::xOffset
	variable Arena2Cif::yOffset
	global dirName
	global faceTables
	global faceClass

	$w.f.list delete 0 end
	if {$resNo == "faces.cif"} then {
		set faceTables [cifFaces]
		set faceClass "::Arena2Cif"
	} elseif {[string match weap*.cif [string tolower $resNo]]} then {
		set faceTables [::Arena2Anime::buildTables $resNo]
		set faceClass "::Arena2Anime"
	} else {
		set faceTables [buildTables $resNo]
		set faceClass "::Arena2Cif"
	}
	set headers [lindex $faceTables $tableHeaders]
	set each 0
	set final [lindex $faceTables $tableCount]
	while {$each < $final} {
		set header [lindex $headers $each]
		set u [shortAt $header $xOffset]
		set v [shortAt $header $yOffset]
		set x [shortAt $header $width]
		set y [shortAt $header $height]
		set image [format "%d (%d,%d) %dx%d" $each $u $v $x $y]
		$w.f.list insert end "$image"
		incr each
	}
	$w.msg configure -text "$resNo"
}

proc floadImage {w x y} {
#		Given the mouse selection at (x,y) in the list box,
#		obtain the selected file name and load the requested
#		inage picture.

	variable Arena2Cif::tableHeaders
	global faceTables
	global dirName
	global faceClass

	Arena2Texture::clearAnimation [fanimators]
	set index [$w.f.list curselection]
	set file [$faceClass\::imagesAt $faceTables $index]
	Arena2Texture::currentRate: 142
	Arena2Texture::animate :: portraita $file
#	portraita configure -file $file
}

proc fcloseFaceDialog { w } {
	global needFaces
	global faces
    Arena2Texture::clearAnimation [fanimators]
	set blob [glob -nocomplain $Arena2Cif::picFile $Arena2Cif::ppmFile]
	if {[llength $blob]} then {
		eval file delete $blob
	}
	set blob [glob -nocomplain [file rootname $Arena2Anime::ppmFile].??]
	if {[llength $blob]} then {
		eval file delete $blob
	}
	destroy $w
	set needFaces 1
	set faces ""
}

proc fbuildFaceDialog { resNo dirName } {
	set w .face1
	catch {destroy $w}
	toplevel $w
	wm title $w "Daggerfall CIFs"
	wm iconname $w "Image2"
	fpositionWindow $w

	label	$w.msg \
			-font {Helvetica 14} \
			-wraplength 4i \
			-justify left \
			-text "Select images from"
	pack	$w.msg \
			-side top

	frame	$w.buttons
	pack	$w.buttons \
			-side bottom \
			-fill x \
			-pady 2m
	button	$w.buttons.dismiss \
			-text Close \
			-command "fcloseFaceDialog $w"
	pack	$w.buttons.dismiss \
			-side left \
			-expand 1

	label	$w.dirLabel \
			-text "Directory:"
	entry	$w.dirName \
			-width 30 \
			-textvariable dirName
	bind	$w.dirName <Return> "floadImageDir $w $resNo"
	frame	$w.spacer1 \
			-height 3m \
			-width 20
	label	$w.fileLabel \
			-text "File:"
	frame	$w.f
	pack	$w.dirLabel $w.dirName $w.spacer1 $w.fileLabel $w.f \
			-side top \
			-anchor w

	listbox	$w.f.list \
			-width 20 \
			-height 10 \
			-yscrollcommand "$w.f.scroll set"
	scrollbar $w.f.scroll \
			-command "$w.f.list yview"
	pack	$w.f.list $w.f.scroll \
			-side left \
			-fill y \
			-expand 1
	bind	$w.f.list <Double-1> "floadImage $w %x %y"

	catch {image delete portraita}
	image	create photo portraita \
			-gamma $Arena2Image::gamma
	frame	$w.spacer2 \
			-height 3m \
			-width 20
	label	$w.imageLabel \
			-text "Image:"
	label	$w.image \
			-image portraita
	pack	$w.spacer2 $w.imageLabel $w.image \
			-side top \
			-anchor w
	floadImageDir $w $resNo
	return $w
}

proc openFaceDialog { w x y } {
	global needFaces
	global faces
	global dirName

	set resNo [$w.f.list get @$x,$y]
	if { $needFaces == 1 } {
		set faces [fbuildFaceDialog $resNo $dirName]
		set needFaces 0
	} else {
		bind $faces.dirName <Return> "floadImageDir $faces $resNo"
	}
}

proc buildDialog { dirName } {
	set w .face
	catch {destroy $w}
	toplevel $w
	wm title $w "Daggerfall CIFs"
	wm iconname $w "Image1"
	fpositionWindow $w

	label	$w.msg \
			-font {Helvetica 14} \
			-wraplength 4i \
			-justify left \
			-text "Select images from"
	pack	$w.msg -side top

	frame	$w.buttons
	pack	$w.buttons \
			-side bottom \
			-fill x \
			-pady 2m
	button	$w.buttons.dismiss \
			-text Close \
			-command "destroy $w"
	pack	$w.buttons.dismiss \
			-side left \
			-expand 1

	label	$w.dirLabel \
			-text "Directory:"
	entry	$w.dirName \
			-width 30 \
			-textvariable dirName
	bind	$w.dirName <Return> "floadDir $w"
	frame	$w.spacer1 \
			-height 3m \
			-width 20
	label	$w.fileLabel \
			-text "File:"
	frame	$w.f
	pack	$w.dirLabel $w.dirName $w.spacer1 $w.fileLabel $w.f \
			-side top \
			-anchor w

	listbox	$w.f.list \
			-width 20 \
			-height 10 \
			-yscrollcommand "$w.f.scroll set"
	scrollbar $w.f.scroll \
			-command "$w.f.list yview"
	pack	$w.f.list $w.f.scroll \
			-side left \
			-fill y -expand 1
	bind	$w.f.list <Double-1> "openFaceDialog $w %x %y"

	floadDir $w
}

#							 ******************
#							** Initialization **
#							 ******************

#	Inherit the installation configuration from the Arena2Artwork
#	namespace when it is available.

if {[llength [namespace children :: ::Arena2Config]] > 0} then {
	set dirName "$Arena2Config::artDir"
}
buildDialog $dirName
