#!/bin/sh
# \
exec wishx "$0" "$@"

#								 ***********
#								** Summary **
#								 ***********

#					  Copyright 2002, Nagual Enterprises
#				Please see COPYING for the complete GNU license

#	(1)	Title:
#				Daggerfall CIF Collection Viewer

#	(2)	Purpose:
#			To browse collections of Daggerfall CIF-style image
#			collections.

#	(3)	Platform dependencies:
#			***  None  ***

#	(4)	Change history:
#			Please see the RCS logs for change history.

#	(5)	Definitions:

#			Namespaces:
#				***  None  ***

#			Exports:
#				***  None  ***

#			Assertions about definitions:
#				***  None  ***

#	(6)	References:

#			Library files:
#				Tcl					--	Base Tcl support
#				Tk					--	Base widget support

#			Imports:
#				Arena2Config		--	Arena2 configuration
#				imgtoppm.tcl		--	True color converter

#			Assertions about the references:
#				***  None  ***

#								 ********
#								** Text **
#								 ********

#							 *****************
#							** Configuration **
#							 *****************

source imgtoppm.tcl
	namespace import -force Arena2Image::buildPalette
	namespace import -force Arena2Image::convertImage
	namespace import -force Arena2Image::convertRaw

global dirName
set dirName "/dos/g/game/dag/arena2"
global imgPpm
set imgPpm "img.ppm"

#							 *****************
#							** Class methods **
#							 *****************

proc gpositionWindow w {
#		Position a new window on the screen.
	wm geometry $w +300+300
}

proc gloadDir {w} {
#		Load a directory listbox with file names.

	global dirName
	$w.f.list delete 0 end
	foreach i [lsort [glob [file join $dirName *.img] [file join $dirName *.bss]]] {
		$w.f.list insert end [file tail $i]
	}
}

proc gloadImage {w x y} {
#		Given the mouse selection at (x,y) in the list box,
#		obtain the selected file name and load the requested
#		inage picture.

	global dirName
	global imgPpm

	dfImage blank
	set img [$w.f.list get [$w.f.list curselection]]
	if {[string match fmap*.img [string tolower $img]]} then {
		set pal $Arena2Image::palette
		if {[Arena2Image::convert [file join $dirName $img] $imgPpm fmap_pal.col]} then {
			dfImage configure -file $imgPpm
		}
		variable Arena2Image::palette $pal
	} else {
		if {[Arena2Image::convert [file join $dirName $img] $imgPpm]} then {
			dfImage configure -file $imgPpm
		}
	}
}

proc gcloseImgDialog { w } {
	global imgPpm
	set blob [glob -nocomplain $imgPpm]
	if {[llength $blob]} then {
		eval file delete $blob
	}
	destroy $w
}

proc gbuildImgDialog { dirName } {
	set w .img1
	catch {destroy $w}
	toplevel $w
	wm title $w "Daggerfall IMG files"
	wm iconname $w "Image2"
	gpositionWindow $w

	label	$w.msg \
			-font {Helvetica 14} \
			-wraplength 4i \
			-justify left \
			-text "Select images from"
	pack	$w.msg \
			-side top

	frame	$w.buttons
	pack	$w.buttons \
			-side bottom \
			-fill x \
			-pady 2m
	button	$w.buttons.dismiss \
			-text Close \
			-command "gcloseImgDialog $w"
	pack	$w.buttons.dismiss \
			-side left \
			-expand 1

	label	$w.dirLabel \
			-text "Directory:"
	entry	$w.dirName \
			-width 30 \
			-textvariable dirName
	bind	$w.dirName <Return> "gloadDir $w"
	frame	$w.spacer1 \
			-height 3m \
			-width 20
	label	$w.fileLabel \
			-text "File:"
	frame	$w.f
	pack	$w.dirLabel $w.dirName $w.spacer1 $w.fileLabel $w.f \
			-side top \
			-anchor w

	listbox	$w.f.list \
			-width 20 \
			-height 10 \
			-yscrollcommand "$w.f.scroll set"
	scrollbar $w.f.scroll \
			-command "$w.f.list yview"
	pack	$w.f.list $w.f.scroll \
			-side left \
			-fill y \
			-expand 1
	bind	$w.f.list <Double-1> "gloadImage $w %x %y"

	catch {image delete dfImage}
	image	create photo dfImage \
			-gamma $Arena2Image::gamma
	frame	$w.spacer2 \
			-height 3m \
			-width 20
	label	$w.imageLabel \
			-text "Image:"
	label	$w.image \
			-image dfImage
	pack	$w.spacer2 $w.imageLabel $w.image \
			-side top \
			-anchor w
	gloadDir $w
	return $w
}

proc openImgDialog { dname } {
	global dirName

	set dirName "$dname"
	gbuildImgDialog $dirName
}

#							 ******************
#							** Initialization **
#							 ******************

#	Inherit the installation configuration from the Arena2Artwork
#	namespace when it is available.

if {[llength [namespace children :: ::Arena2Config]] > 0} then {
	set dirName "$Arena2Config::artDir"
	set imgPpm [file join "$Arena2Config::tmpDir" img.ppm]
}

Arena2Image::buildPalette
openImgDialog $dirName
