#!/bin/sh
# \
exec wishx "$0" "$@"

#								 ***********
#								** Summary **
#								 ***********

#					  Copyright 2002, Nagual Enterprises
#				Please see COPYING for the complete GNU license

#	(1)	Title:
#				Item Catalogue Viewer

#	(2)	Purpose:
#			To wrap a picklist around the basic item catalogue
#			inside fall.exe

#	(3)	Platform dependencies:
#			***  None  ***

#	(4)	Change history:
#			Please see the RCS logs for change history.

#	(5)	Definitions:

#			Namespaces:
#				***  None  ***

#			Exports:
#				***  None  ***

#			Assertions about definitions:
#				The item viewer is entirely global.

#				Hard-coded configuration settings are dynamically
#				updated to reflect the current operating environment.

#	(6)	References:

#			Library files:
#				Tcl					--	Base Tcl support
#				Tk					--	Base widget support

#			Imports:
#				items.tcl			--	Base item accessor
#				texture.tcl			--	Base animator class

#			Assertions about the references:
#				***  None  ***

#								 ********
#								** Text **
#								 ********

source texture.tcl

global dirName
set dirName "/dos/g/game/dag/arena2"

source items.tcl
	namespace import -force Arena2Items::browseItems
	namespace import -force Arena2Items::buildTables
	namespace import -force Arena2Items::picToTxt
	namespace import -force Arena2Items::txtImageAt
	namespace import -force Arena2Texture::animate
	namespace import -force Arena2Texture::clearAnimation

set font {Helvetica 14}
global itemTables

proc ianimators {} {
	set reply {}
	if {[llength [namespace which -variable Arena2Items::itema]]} {
		lappend reply $::Arena2Items::itema
	}
	if {[llength [namespace which -variable Arena2Items::itemb]]} {
		lappend reply $::Arena2Items::itemb
	}
	return "$reply"
}

proc ipositionWindow w {
#		Position a new window on the screen.
	wm geometry $w +300+300
}

proc itmSort { a b } {
	variable Arena2Items::itemName
	set i1 [lindex $a $itemName]
	set i2 [lindex $b $itemName]
	return [ccollate $i1 $i2]
}

proc iloadDir {w} {
#		Load a directory listbox with file names.

	global itemTables
	variable Arena2Items::ExeDir
	variable Arena2Items::itemName

	$w.f.list delete 0 end
	set itemTables [Arena2Items::buildTables]
	set itemTables [lsort -command itmSort $itemTables]
	set each 0
	set size [llength $itemTables]
	while { $each < $size } {
		$w.f.list insert end "[lindex [lindex $itemTables $each] $itemName]"
		incr each
	}
}

proc iloadImage {w x y} {
#		Given the mouse selection at (x,y) in the list box,
#		obtain the selected file name and load the requested
#		image picture.

	global itemTables
	variable Arena2Items::ExeDir
	variable Arena2Items::itemName
	variable Arena2Items::itemPicture1
	variable Arena2Items::itemPicture2
	variable Arena2Texture::tableCount
	set dirName "$ExeDir/arena2"

	set index [$w.f.list curselection]
	set item [lindex $itemTables $index]
	set pic1 [lindex $item $itemPicture1]
	clearAnimation [ianimators]
	if { $pic1 != 0 } then {
		set labl [Arena2Items::txtImageAt [Arena2Items::picToTxt $pic1] item1.00]
		$w.left.image1Label configure -text "Texture [lindex $labl 0]"
		animate ::Arena2Items itema [lindex $labl 1]
#		itema configure -file /tmp/pic.ppm1
	} else {
		$w.left.image1Label configure -text "Image 1:"
		itema blank
	}
	set pic2 [lindex $item $itemPicture2]
	if { $pic2 != 0 } then {
		set labl [Arena2Items::txtImageAt [Arena2Items::picToTxt $pic2] item2.00]
		$w.left.itemLabel configure -text "Texture [lindex $labl 0]"
		animate ::Arena2Items itemb [lindex $labl 1]
#		itemb configure -file /tmp/pic.ppm2
	} else {
		$w.left.itemLabel configure -text "Image 2:"
		itemb blank
	}
}

proc icloseSpriteDialog { w } {
	global needSprites
	global items
	Arena2Texture::clearAnimation [ianimators]
	set blob [glob -nocomplain item1.?? item2.??]
	if {[llength $blob]} then {
		eval file delete $blob
	}
	destroy $w
	set needSprites 1
	set items ""
}

proc ibuildSpriteDialog { dirName } {
	set w .item
	catch {destroy $w}
	toplevel $w
	wm title $w "Daggerfall Items"
	wm iconname $w "Image2"
	ipositionWindow $w

	label	$w.msg \
			-font {Helvetica 14} \
			-wraplength 4i \
			-justify left \
			-text "Select images from"
	pack	$w.msg \
			-side top

	frame	$w.buttons
	pack	$w.buttons \
			-side bottom \
			-fill x \
			-pady 2m
	button	$w.buttons.dismiss \
			-text Close \
			-command "icloseSpriteDialog $w"
	pack	$w.buttons.dismiss \
			-side left \
			-expand 1

	label	$w.dirLabel \
			-text "Directory:"
	entry	$w.dirName \
			-width 30 \
			-textvariable dirName
	bind	$w.dirName <Return> "iloadDir $w"
	frame	$w.spacer1 \
			-height 3m \
			-width 20
	label	$w.fileLabel \
			-text "Item:"
	frame	$w.f
	pack	$w.dirLabel $w.dirName $w.spacer1 $w.fileLabel $w.f -side top -anchor w

	listbox	$w.f.list \
			-width 20 \
			-height 10 \
			-yscrollcommand "$w.f.scroll set"
	scrollbar $w.f.scroll \
			-command "$w.f.list yview"
	pack	$w.f.list $w.f.scroll \
			-side left \
			-fill y \
			-expand 1
	bind	$w.f.list <Double-1> "iloadImage $w %x %y"

	variable Arena2Items::gamma
	catch {image delete itema}
	image	create photo itema \
			-gamma $Arena2Items::gamma
	catch {image delete itemb}
	image	create photo itemb \
			-gamma $Arena2Items::gamma
	frame	$w.left
	frame	$w.right
	pack	$w.left $w.right \
			-side left \
			-expand yes \
			-padx 10 \
			-pady 10 \
			-fill both
	label	$w.left.image1Label \
			-text "Image 1:" \
			-justify left
	label	$w.left.itemLabel \
			-text "Image 2:" \
			-justify left
	pack	$w.left.image1Label $w.left.itemLabel \
			-side top \
			-expand yes \
			-pady 2 \
			-anchor w
	label	$w.right.image1 \
			-image itema \
			-justify left
	label	$w.right.item \
			-image itemb \
			-justify left
	pack	$w.right.image1 $w.right.item \
			-side top \
			-pady 5
	iloadDir $w
	return $w
}
ibuildSpriteDialog $Arena2Items::ExeDir
