#!/bin/sh
# \
exec wishx "$0" "$@"


#								 ***********
#								** Summary **
#								 ***********

#					  Copyright 2002, Nagual Enterprises
#				Please see COPYING for the complete GNU license

#	(1)	Title:
#				Daggerfall Sprites

#	(2)	Purpose:
#			To display and animate any of the Daggerfall textures.

#	(3)	Platform dependencies:
#			***  None  ***

#	(4)	Change history:
#			Please consult the RCS logs for change history.

#	(5)	Definitions:

#			Namespaces:
#				***  None  ***

#			Exports:
#				***  None  ***

#			Assertions about definitions:
#				***  None  ***

#	(6)	References:

#			Library files:
#				Tcl					--	Base Tcl support
#				Tk					--	Base widget support

#			Imports:
#				texture.tcl			--	Base texture access

#			Assertions about the references:
#				***  None  ***

#								 ********
#								** Text **
#								 ********

#							 *****************
#							** Configuration **
#							 *****************

source texture.tcl
	namespace import -force Arena2Texture::animate
	namespace import -force Arena2Texture::clearAnimation
	namespace import -force Arena2Texture::imageAt
	namespace import -force Arena2Texture::imagesAt
	namespace import -force Arena2Texture::shortAt
	namespace import -force Arena2Texture::longAt
	namespace import -force Arena2Texture::buildTables
	namespace import -force Arena2Texture::description

set font {Helvetica 14}
global sprites
global needSprites
set sprites ""
set needSprites 1
variable Arena2Texture::GameDir
global dirName
set dirName "$Arena2Texture::GameDir"

global tables

#							 *****************
#							** Class methods **
#							 *****************

proc spositionWindow w {
#		Position a new window on the screen.
    wm geometry $w +300+300
}

proc sloadDir {w} {
#		Load a directory listbox with file names.

	variable Arena2Texture::GameDir
    set dirName "$Arena2Texture::GameDir"

    $w.f.list delete 0 end
    foreach i [lsort [glob [file join $dirName texture.*]]] {
		set res [file tail $i]
		set resNo [lindex [split $res "."] end]
		$w.f.list insert end "$resNo [description $res]"
    }
}

proc sloadImageDir {w resNo} {
#		Load a listbox with texture image names.

	variable Arena2Texture::GameDir
	variable Arena2Texture::tableHeaders
	variable Arena2Texture::tableCount
	variable Arena2Texture::width
	variable Arena2Texture::height
	variable Arena2Texture::xOffset
	variable Arena2Texture::yOffset
	variable Arena2Texture::tableDesc
    set dirName [file join "$Arena2Texture::GameDir" "texture.$resNo"]
    global tables

    $w.f.list delete 0 end
    set tables [buildTables $resNo]
    set headers [lindex $tables $tableHeaders]
    set each 0
    set final [lindex $tables $tableCount]
    while {$each < $final} {
    	set header [lindex $headers $each]
    	set u [shortAt $header $xOffset]
    	set v [shortAt $header $yOffset]
    	set x [shortAt $header $width]
    	set y [shortAt $header $height]
    	set image [format "%d (%d,%d) %dx%d" $each $u $v $x $y]
    	$w.f.list insert end "$image"
    	incr each
    }
    $w.msg configure -text "[lindex $tables $tableDesc]"
}

proc sloadImage {w x y} {
#		Given the mouse selection at (x,y) in the list box,
#		obtain the selected file name and load the requested
#		inage picture.

	variable Arena2Texture::tableHeaders
	variable Arena2Texture::GameDir
	variable Arena2Texture::ppmFile
    global tables
    set dirName "$Arena2Texture::GameDir"

    set index [$w.f.list curselection]
    clearAnimation [sanimators]
    animate :: spritea [imagesAt $tables $index $Arena2Texture::ppmFile]
}

proc sanimators {} {
	set reply {}
	if {[llength [namespace which -variable spritea]]} then {
		lappend reply $::spritea
	}
	return "$reply"
}

proc scloseSpriteDialog { w } {
	global needSprites
	global sprites
	clearAnimation [sanimators]
	set blob [glob -nocomplain [file rootname $Arena2Texture::ppmFile].??]
	if {[llength $blob]} then {
		eval file delete $blob
	}
	set blob [glob -nocomplain $Arena2Texture::picFile]
	if {[llength $blob]} then {
		eval file delete $blob
	}
	destroy $w
	set needSprites 1
	set sprites ""
}

proc sbuildSpriteDialog { resNo dirName } {
	variable Arena2Config::gamma
	set w .sprite
	catch {destroy $w}
	toplevel $w
	wm title $w "Daggerfall Sprites"
	wm iconname $w "Image2"
	spositionWindow $w

	label	$w.msg \
			-font {Helvetica 14} \
			-wraplength 4i \
			-justify left \
			-text "Select sprites from"
	pack	$w.msg \
			-side top

	frame	$w.buttons
	pack	$w.buttons \
			-side bottom \
			-fill x \
			-pady 2m
	button	$w.buttons.dismiss \
			-text Close \
			-command "scloseSpriteDialog $w"
	pack	$w.buttons.dismiss \
			-side left \
			-expand 1

	label	$w.dirLabel \
			-text "Directory:"
	entry	$w.dirName \
			-width 30 \
			-textvariable dirName
	bind	$w.dirName <Return> "sloadImageDir $w $resNo"
	frame	$w.spacer1 \
			-height 3m \
			-width 20
	scan	$resNo %d res
	label	$w.fileLabel \
			-text "File: [format %#x [expr $res << 7]]"
	frame	$w.f
	pack	$w.dirLabel $w.dirName $w.spacer1 $w.fileLabel $w.f \
			-side top \
			-anchor w

	listbox	$w.f.list \
			-width 20 \
			-height 10 \
			-yscrollcommand "$w.f.scroll set" -selectmode single
	scrollbar $w.f.scroll \
			-command "$w.f.list yview"
	pack	$w.f.list $w.f.scroll \
			-side left \
			-fill y \
			-expand 1
	bind	$w.f.list <Double-1> "sloadImage $w %x %y"
	bind	$w.f.list <Activate> "$w.f.list activate active"

	catch {image delete spritea}
	image	create photo spritea \
			-gamma $Arena2Config::gamma
	frame	$w.spacer2 \
			-height 3m \
			-width 20
	label	$w.imageLabel \
			-text "Image:"
	label	$w.image \
			-image spritea
	pack	$w.spacer2 $w.imageLabel $w.image \
			-side top \
			-anchor w
	sloadImageDir $w $resNo
	return $w
}

proc sopenSpriteDialog { w x y } {
	global needSprites
	global sprites
	global dirName

	set resNo [lindex [split [$w.f.list get @$x,$y] " "] 0]
	if { $needSprites == 1 } {
		set sprites [sbuildSpriteDialog $resNo $dirName]
		set needSprites 0
	} else {
		bind $sprites.dirName <Return> "sloadImageDir $sprites $resNo"
	}
}

proc sbuildDialog { dirName } {
	set w .sprite1
	catch {destroy $w}
	toplevel $w
	wm title $w "Daggerfall Sprites"
	wm iconname $w "Image1"
	spositionWindow $w

	label	$w.msg -font {Helvetica 14} \
			-wraplength 4i \
			-justify left \
			-text "Select textures from"
	pack	$w.msg \
			-side top

	frame	$w.buttons
	pack	$w.buttons \
			-side bottom \
			-fill x \
			-pady 2m
	button	$w.buttons.dismiss \
			-text Close \
			-command "destroy $w"
	pack	$w.buttons.dismiss \
			-side left \
			-expand 1

	label	$w.dirLabel \
			-text "Directory:"
	entry	$w.dirName \
			-width 30 \
			-textvariable dirName
	bind	$w.dirName <Return> "sloadDir $w"
	frame	$w.spacer1 \
			-height 3m \
			-width 20
	label	$w.fileLabel \
			-text "File:"
	frame	$w.f
	pack	$w.dirLabel $w.dirName $w.spacer1 $w.fileLabel $w.f \
			-side top \
			-anchor w

	listbox	$w.f.list \
			-width 20 \
			-height 10 \
			-yscrollcommand "$w.f.scroll set" \
			-selectmode single
	scrollbar $w.f.scroll \
			-command "$w.f.list yview"
	pack	$w.f.list $w.f.scroll \
			-side left \
			-fill y \
			-expand 1
	bind	$w.f.list <Double-1> "sopenSpriteDialog $w %x %y"
	bind	$w <Button> "+$w.f.list selection set active"

	sloadDir $w
}

#							 ******************
#							** Initialization **
#							 ******************

sbuildDialog $dirName
