#!/bin/sh
# \
exec wishx "$0" "$@"


#								 ***********
#								** Summary **
#								 ***********

#					  Copyright 2002, Nagual Enterprises
#				Please see COPYING for the complete GNU license

#	(1)	Title:
#				tfac00i0.rci Viewer

#	(2)	Purpose:
#			To allow viewing of the image contents of tfac00i0.rci.

#	(3)	Platform dependencies:
#			***  None  ***

#	(4)	Change history:
#			Please consult the RCS logs for change history.

#	(5)	Definitions:

#			Namespaces:
#				***  None  ***

#			Exports:
#				***  None  ***

#			Assertions about definitions:
#				tfac00i0.rci differs from other Cif collections in
#				that none of the image contain proper headers.  All
#				are 646x64, and appear to be the portrait plopped
#				into the dialog screen when the PC chats with another
#				NPC in the game.

#	(6)	References:

#			Library files:
#				Tcl					--	Base Tcl support
#				Tk					--	Base widget support

#			Imports:
#				cifimg.tcl			--	*.cif accessor

#			Assertions about the references:
#				***  None  ***

#								 ********
#								** Text **
#								 ********

#							 *****************
#							** Configuration **
#							 *****************


source cifimg.tcl
	namespace import -force Arena2Cif::imageAt
	namespace import -force Arena2Cif::shortAt
	namespace import -force Arena2Cif::buildTables
	namespace import -force Arena2Cif::description
	namespace import -force Arena2Cif::cifFaces

set font {Helvetica 14}
global tfaces
global needTfaces
set tfaces ""
set needTfaces 1
global dirName
global tfacPath
global tmpDir

#	Inherit the installation configuration from the Arena2Artwork
#	namespace when it is available.

if {[llength [namespace children :: ::Arena2Config]] > 0} then {
	set dirName "$Arena2Config::artDir"
	set tfacPath [file join $dirName "tfac00i0.rci"]
	set gamma "$Arena2Config::gamma"
	set tmpDir "$Arena2Config::tmpDir"
} else {
	set dirName "/dos/g/game/dag/arena2"
	set tfacPath "/dos/g/game/dag/arena2/tfac00i0.rci"
	set tmpDir "/tmp"
	set gamma 2.4
}


#							 *****************
#							** Class methods **
#							 *****************

proc tpositionWindow w {
#		Position a new window on the screen.
    wm geometry $w +300+300
}

proc tloadDir {w} {
#		Load a directory listbox with file names.

    $w.f.list delete 0 end
    set each 0
    while { $each < 503 } {
    	$w.f.list insert end "$each"
    	incr each
    }
}

proc textractImage { index dest } {
	global tfacPath

	Arena2Image::convertRaw $tfacPath $dest 64 64 [expr $index * 4096]
}

proc loadFaceImage {w x y} {
#		Given the mouse selection at (x,y) in the list box,
#		obtain the selected file name and load the requested
#		inage picture.

	global tmpDir
    set index [$w.f.list curselection]
    textractImage $index tfac.ppm
    tfacea configure -file tfac.ppm
}

proc tcloseSpriteDialog { w } {
	global needTfaces
	global tfaces
	set blob [glob -nocomplain tfac.pic tfac.ppm]
	if {[llength $blob]} then {
		eval file delete $blob
	}
	destroy $w
	set needTfaces 1
	set tfaces ""
}

proc tbuildSpriteDialog { dirName gamma} {
	set w .tface
	catch {destroy $w}
	toplevel $w
	wm title $w "Daggerfall Faces"
	wm iconname $w "Image2"
	tpositionWindow $w

	label	$w.msg \
			-font {Helvetica 14} \
			-wraplength 4i \
			-justify left \
			-text "Select images from"
	pack	$w.msg \
			-side top

	frame	$w.buttons
	pack	$w.buttons \
			-side bottom \
			-fill x \
			-pady 2m
	button	$w.buttons.dismiss \
			-text Close \
			-command "tcloseSpriteDialog $w"
	pack	$w.buttons.dismiss \
			-side left \
			-expand 1

	label	$w.dirLabel \
			-text "Directory:"
	entry	$w.dirName \
			-width 30 \
			-textvariable dirName
	bind	$w.dirName <Return> "tloadDir $w"
	frame	$w.spacer1 \
			-height 3m \
			-width 20
	label	$w.fileLabel \
			-text "File:"
	frame	$w.f
	pack	$w.dirLabel $w.dirName $w.spacer1 $w.fileLabel $w.f \
			-side top \
			-anchor w

	listbox	$w.f.list \
			-width 20 \
			-height 10 \
			-yscrollcommand "$w.f.scroll set"
	scrollbar $w.f.scroll \
			-command "$w.f.list yview"
	pack	$w.f.list $w.f.scroll \
			-side left \
			-fill y \
			-expand 1
	bind	$w.f.list <Double-1> "loadFaceImage $w %x %y"

	catch {image delete tfacea}
	image	create photo tfacea \
			-gamma $gamma
	frame	$w.spacer2 \
			-height 3m \
			-width 20
	label	$w.imageLabel \
			-text "Image:"
	label	$w.image \
			-image tfacea
	pack	$w.spacer2 $w.imageLabel $w.image \
			-side top \
			-anchor w
	tloadDir $w
	return $w
}

#							 ******************
#							** Initialization **
#							 ******************

tbuildSpriteDialog $dirName $gamma
