#!/bin/sh
# \
exec wishx "$0" "$@"

#								 ***********
#								** Summary **
#								 ***********

#						  Copyright 2002, Nagual Enterprises
#					Please see COPYING for the complete GNU license

#	(1)	Title:
#				Daggerfall Artwork Viewers

#	(2)	Purpose:
#			To display the Daggerfall title screen dispatching
#			the various artwork viewers.

#	(3)	Platform dependencies:
#			***  None  ***

#	(4)	Change history:
#			Please see the RCS logs for change history.

#	(5)	Definitions:

#			Namespaces:
#				Arena2Artwork		--	Artwork main dialog

#			Exports:
#				picklist			--	Method to activate the
#										main dialog

#			Assertions about definitions:
#				Launch the artwork viewer by

#					title.tcl

#	(6)	References:

#			Library files:
#				Tcl					--	Basic Tcl support
#				Tclx				--	Extended Tcl support
#				Tk					--	Basic widget support

#			Imports:
#				Arena2Config		--	Arena2 main configuration

#			Assertions about the references:
#				***  None  ***

#								 ********
#								** Text **
#								 ********

#							 *****************
#							** Configuration **
#							 *****************

package require Tclx

namespace eval Arena2Artwork {
	variable applicationBackground	ShellBackground
	variable background				ShellBackground
	variable buttonActiveBackground	MenuTopShadow
	variable buttonActiveGoreground	PaleTurquoise1
	variable buttonBackground		IconForeground
	variable buttonForeground		White
	variable checkColor				gold
	variable columnBackground		ShellBackground
	variable columnForeground		gold
	variable computeTrough			gold2
	variable daggerTrough			SteelBlue
	variable editBackground			MidnightBlue
	variable editDisabledBackground	SteelBlue
	variable editDisabledForeground	White
	variable editForeground			White
	variable foreground				White
	variable legendBackground		SteelBlue
	variable majorSkillColor		PaleTurquoise1
	variable minorSkillColor		gold
	variable popupBackground		#48f500000000
	variable popupForeground		White
	variable primarySkillColor		LightSkyBlue
	variable rowBackground			ShellBackground
	variable rowForeground			White
	variable sectionBackground		maroon4
	variable sectionForeground		White
	variable selectBackground		orange3
	variable selectForeground		#68f500000000
	variable icon					"dagger.gif"
	variable statusHelp				{
		"Items (shops, piles, corpses)"
		"Cif images (from *.cif)"
		"Images (from *.img)"
		"NPC faces (tfac00i0.rci)"
		"Sprites and patterns (texture.*)"
		"Faction faces (from faction.txt)"
	}

	namespace export picklist
}
namespace import -force Arena2Artwork::picklist

source tes2.cfg

if {[llength [namespace children :: ::Arena2Config]] > 0} then {
	variable Arena2Artwork::pal [file join "$Arena2Config::artDir" "art_pal.col"]

	variable Arena2Artwork::applicationBackground	"$Arena2Config::applicationBackground"
	variable Arena2Artwork::background				"$Arena2Config::background"
	variable Arena2Artwork::buttonActiveBackground	"$Arena2Config::buttonActiveBackground"
	variable Arena2Artwork::buttonActiveForeground	"$Arena2Config::buttonActiveForeground"
	variable Arena2Artwork::buttonBackground		"$Arena2Config::buttonBackground"
	variable Arena2Artwork::buttonForeground		"$Arena2Config::buttonForeground"
	variable Arena2Artwork::checkColor				"$Arena2Config::checkColor"
	variable Arena2Artwork::columnBackground		"$Arena2Config::columnBackground"
	variable Arena2Artwork::columnForeground		"$Arena2Config::columnForeground"
	variable Arena2Artwork::computeTrough			"$Arena2Config::computeTrough"
	variable Arena2Artwork::daggerTrough			"$Arena2Config::daggerTrough"
	variable Arena2Artwork::editBackground			"$Arena2Config::editBackground"
	variable Arena2Artwork::editDisabledBackground	"$Arena2Config::editDisabledBackground"
	variable Arena2Artwork::editDisabledForeground	"$Arena2Config::editDisabledForeground"
	variable Arena2Artwork::editForeground			"$Arena2Config::editForeground"
	variable Arena2Artwork::foreground				"$Arena2Config::foreground"
	variable Arena2Artwork::legendBackground		"$Arena2Config::legendBackground"
	variable Arena2Artwork::majorSkillColor			"$Arena2Config::majorSkillColor"
	variable Arena2Artwork::minorSkillColor			"$Arena2Config::minorSkillColor"
	variable Arena2Artwork::popupBackground			"$Arena2Config::popupBackground"
	variable Arena2Artwork::popupForeground			"$Arena2Config::popupForeground"
	variable Arena2Artwork::primarySkillColor		"$Arena2Config::primarySkillColor"
	variable Arena2Artwork::rowBackground			"$Arena2Config::rowBackground"
	variable Arena2Artwork::rowForeground			"$Arena2Config::rowForeground"
	variable Arena2Artwork::sectionBackground		"$Arena2Config::sectionBackground"
	variable Arena2Artwork::sectionForeground		"$Arena2Config::sectionForeground"
	variable Arena2Artwork::selectBackground		"$Arena2Config::selectBackground"
	variable Arena2Artwork::selectForeground		"$Arena2Config::selectForeground"
	variable Arena2Artwork::gamma					"$Arena2Config::gamma"
}

#							 *****************
#							** Class methods **
#							 *****************

proc Arena2Artwork::aboutBox {} {
	if {$::Arena2Config::hasExtraFont} then {
		tk_messageBox \
			-font "-*-Helvetica-*-r-*-*-17-*-85-85-p-*-*-*" \
			-type ok \
			-title "About Artwork" \
			-message \
"     Daggerfall\xae\n Artwork Browser \n\n\
Copyright (\xa9) 2001\n Nagual Enterprises"
	} else {
		tk_messageBox \
			-type ok \
			-title "About Artwork" \
			-message \
"     Daggerfall\xae\n Artwork Browser \n\n\
Copyright (\xa9) 2001\n Nagual Enterprises"
	}
}

proc Arena2Artwork::invoke tags {
#		Given the user-selected save game index, open an editor on the
#		underlying savetree.dat.

#	set tags [.t tag names $index]
	set i [lsearch -glob $tags invoke-*]
	if {$i < 0} {
		return
	}
	set cursor [.titles cget -cursor]
	.titles configure -cursor watch
	update
	set viewer [string range [lindex $tags $i] 7 end]
	uplevel [list source $viewer.tcl]
	update
	.titles configure -cursor $cursor
}


proc Arena2Artwork::positionWindow w {
#		Position the viewer window at a fixed position on the screen.

	wm geometry $w +300+300
}

proc Arena2Artwork::picklist {font} {
#		Build the initial picklist for save game edits.

	variable applicationBackground
	variable background
	variable foreground
	variable icon
	variable popupBackground
	variable popupForeground
	variable selectBackground
	variable selectForeground
	global tcl_platform
	. configure -background $background
	menu	.menuBar \
			-background $popupBackground \
			-foreground $popupForeground \
			-activebackground $selectBackground \
			-activeforeground $selectForeground \
			-disabledforeground $popupForeground \
			-activeborderwidth 3 \
			-borderwidth 3 \
			-tearoff 0
	.menuBar add cascade \
			-menu .menuBar.file \
			-label "File" \
			-underline 0
	menu	.menuBar.file \
			-background $popupBackground \
			-foreground $popupForeground \
			-activebackground $selectBackground \
			-activeforeground $selectForeground \
			-disabledforeground $popupForeground \
			-tearoff 0

	if {$tcl_platform(platform) == "macintosh"} {
#		On the Mac use the special .apple menu for the about item

		.menuBar add cascade \
				-menu .menuBar.apple
		menu	.menuBar.apple \
				-tearoff 0
		.menuBar.apple add command \
				-label "About..." \
				-command "Arena2Artwork::aboutBox"
	} else {
		.menuBar.file add command \
				-label "About..." \
				-command "Arena2Artwork::aboutBox" \
				-underline 0 \
				-background $popupBackground \
				-foreground $popupForeground \
				-activebackground $selectBackground \
				-activeforeground $selectForeground \
				-accelerator "<F1>"
		.menuBar.file add sep
	}
	.menuBar.file add command \
			-label "Quit" \
			-command "exit" \
			-underline 0 \
			-background $popupBackground \
			-foreground $popupForeground \
			-activebackground $selectBackground \
			-activeforeground $selectForeground \
			-accelerator "Alt-Q"
	.menuBar.file add sep
	.menuBar.file add command \
			-label "Reload" \
			-command "source $::argv0"
	.		configure \
			-menu .menuBar
#	catch {image delete tes2Icon}
#	image create photo tes2Icon
#	tes2Icon configure -file $icon
#	button .b -image tes2Icon
#	wm iconwindow . .b
	bind	. <F1> Arena2Artwork::aboutBox

	frame	.statusBar \
			-background $applicationBackground
	label	.statusBar.lab \
			-text "   " \
			-relief sunken -bd 1 \
			-font -*-Helvetica-Bold-R-Normal--*-120-*-*-*-*-*-* -anchor w \
			-background $applicationBackground
	label	.statusBar.foo \
			-width 4 \
			-relief sunken \
			-bd 1 \
			-font -*-Helvetica-Medium-R-Normal--*-120-*-*-*-*-*-* -anchor w \
			-background $applicationBackground
	pack	.statusBar.lab \
			-side left \
			-padx 2 \
			-expand yes \
			-fill both
	pack	.statusBar.foo \
			-side left \
			-padx 2
	pack	.statusBar \
			-side bottom \
			-fill x \
			-pady 2

	catch {image delete titleImage}
	image	create photo titleImage \
			-gamma 5.0 \
			-file title.gif

	canvas	.titles \
			-selectbackground $selectBackground \
			-selectforeground $selectForeground \
			-highlightbackground $selectBackground \
			-highlightcolor $selectForeground \
			-relief sunken \
			-selectborderwidth 3 \
			-height 200 \
			-width 320
	.titles	create image \
			0 0 \
			-image titleImage \
			-anchor nw
	.titles	create text 10 4 \
			-font system17 \
			-fill White \
			-anchor nw \
			-text " Items " \
			-tags {items select invoke-item status-0}
	.titles	create text 10 24 \
			-font system17 \
			-fill White \
			-anchor nw \
			-text " Cifs " \
			-tags {cifs select invoke-face status-1}
	.titles	create text 10 44 \
			-font system17 \
			-fill White \
			-anchor nw \
			-text " Images " \
			-tags {images select invoke-img status-2}
	.titles	create text 10 64 \
			-font system17 \
			-fill White \
			-anchor nw \
			-text " Faces " \
			-tags {faces select invoke-tfac status-3}
	.titles	create text 10 84 \
			-font system17 \
			-fill White \
			-anchor nw \
			-text " Sprites " \
			-tags {sprites select invoke-sprite status-4}
	.titles	create text 10 104 \
			-font system17 \
			-fill White \
			-anchor nw \
			-text " Factions " \
			-tags {factions select invoke-faction status-5}
	pack	.titles \
			-expand yes \
			-fill both

	foreach item {items cifs images faces sprites factions} {
		.titles bind $item <Enter> "
			.titles select from $item 0
			.titles select to $item end
			Arena2Artwork::showStatus \[.titles gettags $item\]
		"
		.titles bind $item <Leave> "
			.titles itemconfigure $item -fill $foreground
			.titles select clear
			Arena2Artwork::showStatus {}
		"
		.titles bind $item <ButtonRelease-1> "
			Arena2Artwork::invoke \[.titles gettags $item\]
		"
	}
}

proc Arena2Artwork::showStatus tags {
#		Show the name of a save game in the status bar. This procedure
#		is called when the user moves the cursor over a saved game in
#		the list of available games to edit.

	variable statusHelp
	set i [lsearch -glob $tags status-*]
	set cursor [.titles cget -cursor]
	if {$i < 0} {
		.statusBar.lab config -text " "
		set newcursor xterm
	} else {
		set viewer [string range [lindex $tags $i] 7 end]
		.statusBar.lab config -text "[lindex $statusHelp $viewer]"
		set newcursor hand2
	}
	if [string compare $cursor $newcursor] {
		.titles config -cursor $newcursor
	}
}

#							 ******************
#							** Initialization **
#							 ******************

eval destroy [winfo child .]
set font {Helvetica 13}
wm title . "Daggerfall Artwork"
#Arena2Image::buildPalette
Arena2Artwork::picklist $font
